@@ -69,7 +69,7 @@ group.add_argument(
     action="store_true",
 )
 group.add_argument(
-    "--tar",
+    "--export",
     help="Make a tarball of tracked dotfiles @ work-tree/dotfiles.tar.gz",
     action="store_true",
 )
@@ -80,9 +80,9 @@ group.add_argument(
     action="store_true",
 )
 group.add_argument(
-    "-ls",
+    "-l",
     "--list",
-    help="list all files in the repo",
+    help="List all dotfiles in the work tree",
     action="store_true",
 )
 args, extras = parser.parse_known_args()
@@ -104,7 +104,7 @@ elif args.discard:
     dotfiles.discard_changes()
 elif args.restore:
     dotfiles.restore()
-elif args.tar:
+elif args.export:
     dotfiles.make_tar()
 elif args.clip:
     dotfiles.clip()
