@@ -5,7 +5,7 @@
 # Standard Library
 # https://docs.python.org/3/library/functools.html?highlight=functools#functools.cached_property
 from functools import cached_property
-from os import X_OK, access, chdir, getenv
+import os
 from pathlib import Path
 from shutil import which
 from subprocess import run
@@ -14,10 +14,14 @@ from typing import List, Union
 
 from pydymenu import fzf
 
+from mydot.clip import Clipper, find_clipper
 from mydot.console import console
 from mydot.exceptions import MissingRepositoryLocation, WorktreeMissing
 from mydot.system_funcs import script_plus_args
-from mydot.clip import Clipper, find_clipper
+
+
+# Custom Type
+OptionalPath = Union[Path, str, None]
 
 
 class Dotfiles:
@@ -25,8 +29,8 @@ class Dotfiles:
 
     def __init__(
         self,
-        local_bare_repo: Union[Path, str, None] = None,
-        work_tree: Union[Path, str, None] = None,
+        local_bare_repo: OptionalPath = None,
+        work_tree: OptionalPath = None,
     ):
         """Create a new Dotfiles object to manage your repository.
 
@@ -42,17 +46,17 @@ class Dotfiles:
             f"--work-tree={self.work_tree}",
         ]
         self.run_from: Path = Path.cwd()
-        chdir(self.work_tree)
+        os.chdir(self.work_tree)
 
     @staticmethod
-    def _resolve_repo_location(path_loc: Union[str, Path, None]) -> Path:
+    def _resolve_repo_location(path_loc: OptionalPath) -> Path:
         """Decides which dotfile repository location will be used.
 
         When None is given, try to read $DOTFILES from environment.
         When a location is specified return it's Path
         """
         if path_loc is None:
-            if env_val := getenv("DOTFILES", default=None):
+            if env_val := os.getenv("DOTFILES", default=None):
                 return Path(env_val)
             else:
                 raise MissingRepositoryLocation(
@@ -62,7 +66,7 @@ class Dotfiles:
             return Path(path_loc) if isinstance(path_loc, str) else path_loc
 
     @staticmethod
-    def _resolve_work_tree_location(dir: Union[Path, str, None]) -> Path:
+    def _resolve_work_tree_location(dir: OptionalPath) -> Path:
         """Define work tree location.
 
         When None given presume Path.home()
@@ -70,7 +74,7 @@ class Dotfiles:
         if dir is None:
             return Path.home()
         else:
-            work_tree = Path(dir) if isinstance(dir, str) else dir
+            work_tree: Path = Path(dir) if isinstance(dir, str) else dir
             if work_tree.is_dir():
                 return work_tree
             else:
@@ -133,7 +137,6 @@ class Dotfiles:
 
     def run_executable(self) -> str:
         """Interactively choose an executable to run. Optionally add arguements."""
-        chdir(self.run_from)
         exe = fzf(
             self.executables,
             prompt="Pick a file to run: ",
@@ -143,6 +146,7 @@ class Dotfiles:
         if exe is None:
             sys_exit("No selection made. Cancelling action.")
         else:
+            os.chdir(self.run_from)
             command = script_plus_args(Path(self.work_tree) / exe[0])
             run(command)
             return str(exe[0])
@@ -207,8 +211,13 @@ class Dotfiles:
     def make_tar(self) -> Path:
         """Make tarball of dotfiles @ self.work_tree / 'dotfiles.tar.gz'."""
         # TODO: incorporate a 'privatemask' feature
+        os.chdir(self.work_tree)
         tarball = self.work_tree / "dotfiles.tar.gz"
-        tar_cmd = ["tar", "cvzf", tarball] + self.list_all
+        tar_cmd = (
+            ["tar", "cvzf", tarball]
+            + self.list_all
+            + [self.bare_repo.relative_to(self.work_tree)]
+        )
         run(tar_cmd)
         print("-" * 20)
         print(
@@ -223,7 +232,7 @@ class Dotfiles:
             clipper = find_clipper()
         clips = fzf(
             self.list_all,
-            prompt="Pick files to add to the clipboard.",
+            prompt="Pick files to add to the clipboard: ",
             multi=True,
             preview=f"{self.preview_app}" + " {}",
         )
@@ -308,7 +317,7 @@ class Dotfiles:
         return [
             str(Path(e).relative_to(self.work_tree))
             for e in self.list_all_as_path
-            if access(e, X_OK)
+            if os.access(e, os.X_OK)
         ]
 
     def freshen(self) -> None:
@@ -378,7 +387,7 @@ class Dotfiles:
     @cached_property
     def editor(self) -> str:
         """Preference: $EDITOR > nvim > vim > nano > emacs."""
-        if env := getenv("EDITOR", None):
+        if env := os.getenv("EDITOR", None):
             return env
         else:
             for prog in ["nvim", "vim", "nano", "emacs"]:
@@ -389,7 +398,7 @@ class Dotfiles:
 
     def git_passthrough(self, args: List[str]):
         """Send commands to git with --git-dir and --work-tree set."""
-        chdir(self.run_from)
+        os.chdir(self.run_from)
         run(self._git_base + args[1:])
 
 
